@@ -16,6 +16,7 @@ from basis.cli.services.list import (
     paginated_graph_components,
 )
 from basis.cli.services.lookup import IdLookup
+from basis.cli.services.organizations import paginated_organizations
 from basis.cli.services.output import sprint, abort_on_error
 
 
@@ -59,6 +60,16 @@ def environments(
     _print_objects(es, print_json)
 
 
+@list_command.command()
+def organizations(
+    print_json: bool = Option(False, "--json", help=_json_help),
+):
+    """List organizations"""
+    with abort_on_error("Error listing organizations"):
+        es = list(paginated_organizations())
+    _print_objects(es, print_json)
+
+
 _node_help = "The path to the node to get logs for"
 
 
@@ -85,25 +96,28 @@ def logs(
 
 _port_help = "The name of the output port"
 
+_store_name_help = "The name of the store to get the latest output for"
+_graph_help = "The location of the graph.yml file for the graph"
+
 
 @list_command.command()
 def output(
     print_json: bool = Option(False, "--json", help=_json_help),
     organization: str = Option("", "-o", "--organization", help=_organization_help),
     environment: str = Option("", "-e", "--environment", help=_environment_help),
-    node: Path = Argument(..., exists=True, help=_node_help),
-    port: str = Argument(..., help=_port_help),
+    graph: Path = Option("", "-g", "--graph-path", help=_graph_help),
+    store_name: str = Argument(..., exists=True, help=_store_name_help),
 ):
     """List data sent to an output port of a from the most recent run of a node"""
     ids = IdLookup(
         environment_name=environment,
         organization_name=organization,
-        node_file_path=node,
+        explicit_graph_path=graph,
     )
 
     with abort_on_error("Could not get node data"):
         data = list(
-            paginated_output_data(ids.environment_id, ids.graph_id, ids.node_id, port)
+            paginated_output_data(ids.environment_id, ids.graph_id, store_name)
         )
     _print_objects(data, print_json)
 
@@ -131,7 +145,7 @@ def webhooks(
 
 
 @list_command.command()
-def components(print_json: bool = Option(False, "--json", help=_json_help),):
+def components(print_json: bool = Option(False, "--json", help=_json_help)):
     """List available graph components that you can add to your graphs"""
     with abort_on_error("Could not get components"):
         data = list(paginated_graph_components())
