@@ -5,10 +5,8 @@ from typer import Option, Argument
 from basis.cli.services.deploy import deploy_graph_version
 from basis.cli.services.graph_components import create_graph_component
 from basis.cli.services.lookup import IdLookup
-from basis.cli.services.output import sprint, abort_on_error, abort
+from basis.cli.services.output import sprint, abort_on_error
 from basis.cli.services.upload import upload_graph_version
-from basis.configuration.base import load_yaml
-from basis.configuration.edit import GraphConfigEditor
 
 _graph_help = "The location of the graph.yml file for the graph to upload"
 _deploy_help = "Whether or not to automatically deploy the graph after upload"
@@ -32,15 +30,20 @@ def upload(
     )
 
     with abort_on_error("Upload failed"):
-        resp = upload_graph_version(ids.graph_file_path, ids.organization_id)
+        resp = upload_graph_version(
+            ids.graph_file_path,
+            ids.organization_id,
+            add_missing_node_ids=not publish_component,
+        )
+
     graph_version_id = resp["uid"]
     ui_url = resp["ui_url"]
+    manifest = resp["manifest"]
     sprint(f"\n[success]Uploaded new graph version with id [b]{graph_version_id}")
-
-    if deploy:
-        with abort_on_error("Deploy failed"):
-            deploy_graph_version(graph_version_id, ids.environment_id)
-        sprint(f"[success]Graph deployed")
+    if manifest.get("errors"):
+        sprint(f"[error]Graph contains the following errors:")
+        for error in manifest["errors"]:
+            sprint(f"\t[error]{error}")
 
     if publish_component:
         with abort_on_error("Error creating component"):
@@ -55,5 +58,9 @@ def upload(
                 f"with versions [b]{resp_versions}[/b] "
                 f"at id [b]{resp_id}"
             )
+    elif deploy:
+        with abort_on_error("Deploy failed"):
+            deploy_graph_version(graph_version_id, ids.environment_id)
+        sprint(f"[success]Graph deployed")
 
     sprint(f"\n[info]Visit [code]{ui_url}[/code] to view your graph")
